@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2010-04-06 14:58:53 +0200 (Tue, 06 Apr 2010) $ by $Author: tack $
- *     $Revision: 10649 $
+ *     $Date: 2011-08-25 18:43:31 +1000 (Thu, 25 Aug 2011) $ by $Author: tack $
+ *     $Revision: 12352 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -89,6 +89,11 @@ namespace Gecode { namespace Gist {
     return t->getStream();
   }
   
+  void
+  TextOutput::flush(void) {
+    t->flush();
+  }
+  
   void
   TextOutput::addHtml(const char* s) {
     t->insertHtml(s);
