@@ -7,8 +7,8 @@
  *     Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-31 01:08:42 +1000 (Sat, 31 Jul 2010) $ by $Author: tack $
+ *     $Revision: 11315 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -38,18 +38,19 @@
 namespace Gecode { namespace Gist {
 
   template<class Cursor>
-  NodeVisitor<Cursor>::NodeVisitor(Cursor& c0) : c(c0) {}
+  forceinline
+  NodeVisitor<Cursor>::NodeVisitor(const Cursor& c0) : c(c0) {}
 
   template<class Cursor>
-  void
-  NodeVisitor<Cursor>::setCursor(Cursor& c0) { c = c0; }
+  forceinline void
+  NodeVisitor<Cursor>::setCursor(const Cursor& c0) { c = c0; }
 
   template<class Cursor>
-  Cursor&
+  forceinline Cursor&
   NodeVisitor<Cursor>::getCursor(void) { return c; }
 
   template<class Cursor>
-  void
+  forceinline void
   PostorderNodeVisitor<Cursor>::moveToLeaf(void) {
     while (c.mayMoveDownwards()) {
         c.moveDownwards();
@@ -57,13 +58,13 @@ namespace Gecode { namespace Gist {
   }
 
   template<class Cursor>
-  PostorderNodeVisitor<Cursor>::PostorderNodeVisitor(Cursor& c0)
+  PostorderNodeVisitor<Cursor>::PostorderNodeVisitor(const Cursor& c0)
     : NodeVisitor<Cursor>(c0) {
     moveToLeaf();
   }
 
   template<class Cursor>
-  bool
+  forceinline bool
   PostorderNodeVisitor<Cursor>::next(void) {
     c.processCurrentNode();
     if (c.mayMoveSidewards()) {
@@ -78,7 +79,13 @@ namespace Gecode { namespace Gist {
   }
 
   template<class Cursor>
-  bool
+  forceinline void
+  PostorderNodeVisitor<Cursor>::run(void) {
+    while (next()) {}
+  }
+
+  template<class Cursor>
+  forceinline bool
   PreorderNodeVisitor<Cursor>::backtrack(void) {
     while (! c.mayMoveSidewards() && c.mayMoveUpwards()) {
       c.moveUpwards();
@@ -92,11 +99,11 @@ namespace Gecode { namespace Gist {
   }
 
   template<class Cursor>
-  PreorderNodeVisitor<Cursor>::PreorderNodeVisitor(Cursor& c0)
+  PreorderNodeVisitor<Cursor>::PreorderNodeVisitor(const Cursor& c0)
     : NodeVisitor<Cursor>(c0) {}
 
   template<class Cursor>
-  bool
+  forceinline bool
   PreorderNodeVisitor<Cursor>::next(void) {
     c.processCurrentNode();
     if (c.mayMoveDownwards()) {
@@ -108,6 +115,12 @@ namespace Gecode { namespace Gist {
     }
     return true;
   }
+
+  template<class Cursor>
+  forceinline void
+  PreorderNodeVisitor<Cursor>::run(void) {
+    while (next()) {}
+  }
 }}
 
 // STATISTICS: gist-any
