@@ -7,8 +7,8 @@
  *     Christian Schulte, 2007
  *
  *  Last modified:
- *     $Date: 2010-03-03 17:32:21 +0100 (Wed, 03 Mar 2010) $ by $Author: schulte $
- *     $Revision: 10364 $
+ *     $Date: 2011-07-07 19:23:22 +1000 (Thu, 07 Jul 2011) $ by $Author: schulte $
+ *     $Revision: 12155 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -84,22 +84,45 @@ namespace Gecode { namespace Int { namespace Channel {
 
   forceinline
   LinkMulti::LinkMulti(Space& home, bool share, LinkMulti& p)
-    : MixNaryOnePropagator<BoolView,PC_BOOL_VAL,IntView,PC_INT_DOM>
-  (home,share,p), o(p.o) {}
+    : MixNaryOnePropagator<BoolView,PC_BOOL_NONE,IntView,PC_INT_DOM>
+  (home,share,p), status(S_NONE), o(p.o) {
+    assert(p.status == S_NONE);
+    c.update(home,share,p.c);
+  }
 
   Actor*
   LinkMulti::copy(Space& home, bool share) {
     return new (home) LinkMulti(home,share,*this);
   }
 
+  forceinline size_t
+  LinkMulti::dispose(Space& home) {
+    Advisors<Advisor> as(c);
+    x.cancel(home,as.advisor());
+    c.dispose(home);
+    (void) MixNaryOnePropagator<BoolView,PC_BOOL_NONE,IntView,PC_INT_DOM>
+      ::dispose(home);
+    return sizeof(*this);
+  }
+
   PropCost
   LinkMulti::cost(const Space&, const ModEventDelta& med) const {
-    if (IntView::me(med) == ME_INT_VAL)
+    if ((status == S_ONE) || (IntView::me(med) == ME_INT_VAL))
       return PropCost::unary(PropCost::LO);
     else
       return PropCost::linear(PropCost::LO, x.size());
   }
 
+  ExecStatus
+  LinkMulti::advise(Space&, Advisor&, const Delta& d) {
+    if (status == S_RUN)
+      return ES_FIX;
+    // Detect a one
+    if (BoolView::one(d))
+      status = S_ONE;
+    return ES_NOFIX;
+  }
+
   ExecStatus
   LinkMulti::propagate(Space& home, const ModEventDelta& med) {
     int n = x.size();
@@ -108,6 +131,7 @@ namespace Gecode { namespace Int { namespace Channel {
     assert((y.min()-o >= 0) && (y.max()-o < n));
 
     if (y.assigned()) {
+      status = S_RUN;
       int j=y.val()-o;
       GECODE_ME_CHECK(x[j].one(home));
       for (int i=0; i<j; i++)
@@ -117,6 +141,23 @@ namespace Gecode { namespace Int { namespace Channel {
       return home.ES_SUBSUMED(*this);
     }
 
+    // Check whether there is a one
+    if (status == S_ONE) {
+      status = S_RUN;
+      for (int i=0; true; i++)
+        if (x[i].one()) {
+          for (int j=0; j<i; j++)
+            GECODE_ME_CHECK(x[j].zero(home));
+          for (int j=i+1; j<n; j++)
+            GECODE_ME_CHECK(x[j].zero(home));
+          GECODE_ME_CHECK(y.eq(home,i+o));
+          return home.ES_SUBSUMED(*this);
+        }
+      GECODE_NEVER;
+    }
+
+    status = S_RUN;
+
   redo:
 
     // Assign all Boolean views to zero that are outside bounds
@@ -164,17 +205,6 @@ namespace Gecode { namespace Int { namespace Channel {
     if ((y.min() > o) || (y.max() < o+n-1))
       goto redo;
 
-    // Check whether there is a one somewhere else
-    for (int i=n; i--; )
-      if (x[i].one()) {
-        for (int j=0; j<i; j++)
-          GECODE_ME_CHECK(x[j].zero(home));
-        for (int j=i+1; j<n; j++)
-          GECODE_ME_CHECK(x[j].zero(home));
-        GECODE_ME_CHECK(y.eq(home,i+o));
-        return home.ES_SUBSUMED(*this);
-      }
-
     assert((n >= 2) && x[0].none() && x[n-1].none());
     assert((y.min()-o == 0) && (y.max()-o == n-1));
 
@@ -201,6 +231,7 @@ namespace Gecode { namespace Int { namespace Channel {
       BoolIter bv(x,o);
       GECODE_ME_CHECK(y.minus_v(home,bv,false));
     }
+    status = S_NONE;
     return ES_FIX;
   }
 
