@@ -7,8 +7,8 @@
  *     Christian Schulte, 2007
  *
  *  Last modified:
- *     $Date: 2011-07-07 11:23:22 +0200 (Thu, 07 Jul 2011) $ by $Author: schulte $
- *     $Revision: 12155 $
+ *     $Date: 2012-02-22 16:04:20 +1100 (Wed, 22 Feb 2012) $ by $Author: tack $
+ *     $Revision: 12537 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -70,6 +70,8 @@ namespace Gecode { namespace Int { namespace Channel {
             GECODE_ME_CHECK(x[j].zero(home));
           GECODE_ME_CHECK(y.eq(home,o+i));
           return ES_OK;
+        } else if (x[i].zero()) {
+          GECODE_ME_CHECK(y.nq(home,o+i));
         }
       (void) new (home) LinkMulti(home,x,y,o);
     }
