@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -73,11 +73,11 @@ namespace Gecode { namespace Int { namespace Distinct {
     GECODE_ME_CHECK(x2.nq(home,x0.val()));      \
     if (x1.assigned()) {                        \
       GECODE_ME_CHECK(x2.nq(home,x1.val()));    \
-      return ES_SUBSUMED(*this,home);            \
+      return home.ES_SUBSUMED(*this);            \
     }                                           \
     if (x2.assigned()) {                        \
       GECODE_ME_CHECK(x1.nq(home,x2.val()));    \
-      return ES_SUBSUMED(*this,home);            \
+      return home.ES_SUBSUMED(*this);            \
     }                                           \
     return ES_FIX;                              \
   }
