@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2010-08-23 18:53:25 +0200 (Mon, 23 Aug 2010) $ by $Author: tack $
- *     $Revision: 11358 $
+ *     $Date: 2012-02-22 16:04:20 +1100 (Wed, 22 Feb 2012) $ by $Author: tack $
+ *     $Revision: 12537 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -54,6 +54,12 @@ namespace Gecode { namespace Int { namespace Dom {
       GECODE_ME_CHECK(b.zero(home));
     } else if ((min <= x.min()) && (x.max() <= max)) {
       GECODE_ME_CHECK(b.one(home));
+    } else if (b.one()) {
+      GECODE_ME_CHECK(x.gq(home,min));
+      GECODE_ME_CHECK(x.lq(home,max));
+    } else if (b.zero()) {
+      Iter::Ranges::Singleton r(min,max);
+      GECODE_ME_CHECK(x.minus_r(home,r,false));
     } else {
       (void) new (home) ReRange<View>(home,x,min,max,b);
     }
