@@ -7,8 +7,8 @@
  *     Christian Schulte, 2009
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,14 +44,14 @@ namespace Gecode {
   wait(Home home, IntVar x, void (*c)(Space& home),
        IntConLevel) {
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Kernel::UnaryWait<Int::IntView>::post(home,x,c));
+    GECODE_ES_FAIL(Kernel::UnaryWait<Int::IntView>::post(home,x,c));
   }
 
   void
   wait(Home home, BoolVar x, void (*c)(Space& home),
        IntConLevel) {
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Kernel::UnaryWait<Int::BoolView>::post(home,x,c));
+    GECODE_ES_FAIL(Kernel::UnaryWait<Int::BoolView>::post(home,x,c));
   }
 
   void
@@ -59,7 +59,7 @@ namespace Gecode {
        IntConLevel) {
     if (home.failed()) return;
     ViewArray<Int::IntView> xv(home,x);
-    GECODE_ES_FAIL(home,Kernel::NaryWait<Int::IntView>::post(home,xv,c));
+    GECODE_ES_FAIL(Kernel::NaryWait<Int::IntView>::post(home,xv,c));
   }
 
   void
@@ -67,7 +67,7 @@ namespace Gecode {
        IntConLevel) {
     if (home.failed()) return;
     ViewArray<Int::BoolView> xv(home,x);
-    GECODE_ES_FAIL(home,Kernel::NaryWait<Int::BoolView>::post(home,xv,c));
+    GECODE_ES_FAIL(Kernel::NaryWait<Int::BoolView>::post(home,xv,c));
   }
 
   void
@@ -75,7 +75,7 @@ namespace Gecode {
        void (*t)(Space& home), void (*e)(Space& home),
        IntConLevel) {
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Int::Exec::When::post(home,x,t,e));
+    GECODE_ES_FAIL(Int::Exec::When::post(home,x,t,e));
   }
 
 }
