@@ -7,8 +7,8 @@
  *     Christian Schulte, 2006
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -291,7 +291,7 @@ namespace Gecode { namespace Int { namespace Linear {
 
     if (p.empty() && n.empty()) {
       GECODE_ME_CHECK(x.eq(home,-c));
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
 
     sl_p += x.max() + c;
@@ -377,7 +377,7 @@ namespace Gecode { namespace Int { namespace Linear {
       }
     } while (mod != 0);
 
-    return (sl_p == -su_n) ? ES_SUBSUMED(*this,sizeof(*this)) : ES_FIX;
+    return (sl_p == -su_n) ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 
@@ -530,7 +530,7 @@ namespace Gecode { namespace Int { namespace Linear {
     }
 
     if (p.empty() && n.empty())
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
 
     return es;
   }
@@ -643,7 +643,7 @@ namespace Gecode { namespace Int { namespace Linear {
 
     if (p.empty() && n.empty()) {
       GECODE_ME_CHECK(x.nq(home,-c));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
 
     if (x.assigned()) {
@@ -654,7 +654,7 @@ namespace Gecode { namespace Int { namespace Linear {
         } else if (r == 0) {
           GECODE_ME_CHECK(n.fst()->x.one_none(home));
         }
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
       if ((p.size() == 1) && n.empty()) {
         if (r == p.fst()->a) {
@@ -662,7 +662,7 @@ namespace Gecode { namespace Int { namespace Linear {
         } else if (r == 0) {
           GECODE_ME_CHECK(p.fst()->x.one_none(home));
         }
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       }
     }
     return ES_FIX;
