@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -52,7 +52,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class XV, class YV>
   forceinline size_t
   LinBoolView<XV,YV>::dispose(Space& home) {
-    assert(!home.failed());
     x.cancel(home,*this,PC_INT_VAL);
     y.cancel(home,*this,PC_INT_BND);
     (void) Propagator::dispose(home);
@@ -141,18 +140,18 @@ namespace Gecode { namespace Int { namespace Linear {
     GECODE_ME_CHECK(y.lq(home,n-c));
     GECODE_ME_CHECK(y.gq(home,-c));
     if (n == 0)
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     if (y.min()+c == n) {
       assert(y.assigned());
       for (int i = n; i--; )
         GECODE_ME_CHECK(x[i].one_none(home));
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
     if (y.max()+c == 0) {
       assert(y.assigned());
       for (int i = n; i--; )
         GECODE_ME_CHECK(x[i].zero_none(home));
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
     if (y.assigned())
       GECODE_REWRITE(*this,EqBoolInt<XV>::post(home(*this),x,y.val()+c));
@@ -225,10 +224,10 @@ namespace Gecode { namespace Int { namespace Linear {
       }
     x.size(n);
     if ((n-c < y.min() ) || (-c > y.max()))
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     if (n == 0) {
       GECODE_ME_CHECK(y.nq(home,-c));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     if ((n == 1) && y.assigned()) {
       if (y.val()+c == 1) {
@@ -237,7 +236,7 @@ namespace Gecode { namespace Int { namespace Linear {
         assert(y.val()+c == 0);
         GECODE_ME_CHECK(x[0].one_none(home));
       }
-      return ES_SUBSUMED(*this,sizeof(*this));
+      return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
@@ -303,11 +302,11 @@ namespace Gecode { namespace Int { namespace Linear {
     x.size(n);
     GECODE_ME_CHECK(y.lq(home,n-c));
     if (-c >= y.max())
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     if (y.min()+c == n) {
       for (int i = n; i--; )
         GECODE_ME_CHECK(x[i].one_none(home));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     if (y.assigned())
       GECODE_REWRITE(*this,GqBoolInt<XV>::post(home(*this),x,y.val()+c));
