@@ -7,8 +7,8 @@
  *     Christian Schulte, 2003
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -79,7 +79,6 @@ namespace Gecode { namespace Int { namespace Linear {
   template<class Val, class A, class B, class C, PropCond pc>
   forceinline size_t
   LinTer<Val,A,B,C,pc>::dispose(Space& home) {
-    assert(!home.failed());
     x0.cancel(home,*this,pc);
     x1.cancel(home,*this,pc);
     x2.cancel(home,*this,pc);
@@ -159,7 +158,7 @@ namespace Gecode { namespace Int { namespace Linear {
                     TM_X0_MIN | TM_X1_MIN);
     } while (bm);
     return (x0.assigned() && x1.assigned()) ?
-      ES_SUBSUMED(*this,sizeof(*this)) : ES_FIX;
+      home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 #undef GECODE_INT_PV
@@ -207,15 +206,15 @@ namespace Gecode { namespace Int { namespace Linear {
   NqTer<Val,A,B,C>::propagate(Space& home, const ModEventDelta&) {
     if (x0.assigned() && x1.assigned()) {
       GECODE_ME_CHECK(x2.nq(home,c-x0.val()-x1.val()));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     if (x0.assigned() && x2.assigned()) {
       GECODE_ME_CHECK(x1.nq(home,c-x0.val()-x2.val()));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     if (x1.assigned() && x2.assigned()) {
       GECODE_ME_CHECK(x0.nq(home,c-x1.val()-x2.val()));
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
@@ -265,7 +264,7 @@ namespace Gecode { namespace Int { namespace Linear {
     GECODE_ME_CHECK(x1.lq(home,c-x0.min()-x2.min()));
     GECODE_ME_CHECK(x2.lq(home,c-x0.min()-x1.min()));
     return (x0.max()+x1.max()+x2.max() <= c) ?
-      ES_SUBSUMED(*this,home) : ES_FIX;
+      home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 }}}
