@@ -7,8 +7,8 @@
  *     Christian Schulte, 2002
  *
  *  Last modified:
- *     $Date: 2010-06-30 14:31:56 +0200 (Wed, 30 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11134 $
+ *     $Date: 2010-09-01 00:19:34 +1000 (Wed, 01 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11366 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -40,7 +40,7 @@
 namespace Gecode {
 
   IntVar::IntVar(Space& home, int min, int max)
-    : Var<Int::IntVarImp>(new (home) Int::IntVarImp(home,min,max)) {
+    : VarImpVar<Int::IntVarImp>(new (home) Int::IntVarImp(home,min,max)) {
     Int::Limits::check(min,"IntVar::IntVar");
     Int::Limits::check(max,"IntVar::IntVar");
     if (min > max)
@@ -48,7 +48,7 @@ namespace Gecode {
   }
 
   IntVar::IntVar(Space& home, const IntSet& ds)
-    : Var<Int::IntVarImp>(new (home) Int::IntVarImp(home,ds)) {
+    : VarImpVar<Int::IntVarImp>(new (home) Int::IntVarImp(home,ds)) {
     Int::Limits::check(ds.min(),"IntVar::IntVar");
     Int::Limits::check(ds.max(),"IntVar::IntVar");
     if (ds.size() == 0)
