@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-29 01:35:33 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,9 +44,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
    */
   template<class I>
   class AddRange : public MinMax {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
   protected:
     /// Iterator to which the range is to be added
     I i;
