@@ -9,8 +9,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-29 01:35:33 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -51,9 +51,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
 
   template<int UMIN, int UMAX, class I>
   class Compl : public MinMax {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
   protected:
     /// Iterator to compute complement for
     I i;
@@ -90,9 +87,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
 
   template<class I>
   class ComplVal : public MinMax {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
   protected:
     /// Values describing the universe set
     int UMIN, UMAX;
