@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-29 01:35:33 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -47,9 +47,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
    */
   template<class I, class M, bool strict=true>
   class Map {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
   public:
     /// \name Constructors and initialization
     //@{
@@ -87,9 +84,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
   /// Specialized mapping of ranges for non-strict maps
   template<class I, class M>
   class Map<I,M,false> : public MinMax {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
   protected:
     /// Input range
     I i;
@@ -122,9 +116,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
   /// Specialized mapping of ranges for strict maps
   template<class I, class M>
   class Map<I,M,true> {
-  private:
-    /// Check that \a I is a range iterator;
-    IsRangeIter<I> _checkI;
   protected:
     /// Input range iterator
     I i;
