@@ -9,8 +9,8 @@
  *    Guido Tack, 2006
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-29 01:35:33 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -49,9 +49,6 @@ namespace Gecode { namespace Iter { namespace Ranges {
 
   template<class J>
   class SingletonAppend : public MinMax {
-  private:
-    /// Check that \a J is a range iterator;
-    IsRangeIter<J> _checkJ;
   protected:
     /// Iterator to be appended
     J j;
