@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-12-17 15:16:53 +0100 (Thu, 17 Dec 2009) $ by $Author: schulte $
- *     $Revision: 10207 $
+ *     $Date: 2010-07-29 01:35:33 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -44,7 +44,7 @@ namespace Gecode { namespace Iter { namespace Values {
    */
   template<class BS>
   class BitSet {
-  private:
+  protected:
     /// Bitset
     const BS& bs;
     /// Current value
