@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-29 01:35:33 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,15 +45,13 @@ namespace Gecode { namespace Iter { namespace Values {
 
   template<class I, class J>
   class Inter  {
-  private:
+  protected:
     /// First iterator
     I i;
     /// Second iterator
     J j;
     /// Find next element from intersection
     void next(void);
-  private:
-    IsValueIter<I> constraintI; IsValueIter<J> constraintJ;
   public:
     /// \name Constructors and initialization
     //@{
