@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-29 01:35:33 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11294 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -48,9 +48,6 @@ namespace Gecode { namespace Iter { namespace Values {
    */
   template<class I>
   class ToRanges : public Ranges::MinMax {
-  private:
-    /// Check that \a I is a value iterator;
-    IsValueIter<I> _checkI;
   protected:
     /// Value iterator used
     I i;
