@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2011-02-02 00:31:23 +1100 (Wed, 02 Feb 2011) $ by $Author: schulte $
+ *     $Revision: 11595 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,7 +45,7 @@ namespace Gecode { namespace Iter { namespace Values {
 
   template<class I, class J>
   class Union  {
-  private:
+  protected:
     /// First iterator
     I i;
     /// Second iterator
@@ -54,8 +54,6 @@ namespace Gecode { namespace Iter { namespace Values {
     int v;
     /// Whether iterator is done
     bool done;
-  private:
-    IsValueIter<I> constraintI; IsValueIter<J> constraintJ;
   public:
     /// \name Constructors and initialization
     //@{
@@ -85,7 +83,7 @@ namespace Gecode { namespace Iter { namespace Values {
 
   template<class I, class J>
   forceinline
-  Union<I,J>::Union(void) {}
+  Union<I,J>::Union(void) : v(0) {}
 
   template<class I, class J>
   forceinline void
@@ -112,13 +110,13 @@ namespace Gecode { namespace Iter { namespace Values {
   template<class I, class J>
   inline void
   Union<I,J>::init(I& i0, J& j0) {
-    i=i0; j=j0; done=false;
+    i=i0; j=j0; v=0; done=false;
     operator ++();
   }
 
   template<class I, class J>
   forceinline
-  Union<I,J>::Union(I& i0, J& j0) : i(i0), j(j0), done(false) {
+  Union<I,J>::Union(I& i0, J& j0) : i(i0), j(j0), v(0), done(false) {
     operator ++();
   }
 
