@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-08-26 20:56:42 +0200 (Wed, 26 Aug 2009) $ by $Author: schulte $
- *     $Revision: 9631 $
+ *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -67,7 +67,7 @@
  * To be used inside post functions.
  * \ingroup TaskActor
  */
-#define GECODE_ME_FAIL(home,me) do {            \
+#define GECODE_ME_FAIL(me) do {                 \
   if (::Gecode::me_failed(me)) {                \
     (home).fail();                              \
     return;                                     \
@@ -93,7 +93,7 @@
  *
  * \ingroup TaskActor
  */
-#define GECODE_ES_FAIL(home,es) do {                            \
+#define GECODE_ES_FAIL(es) do {                                 \
     ::Gecode::ExecStatus __es__ ## __LINE__ = (es);             \
     assert(__es__ ## __LINE__ != ::Gecode::__ES_SUBSUMED);      \
     if (__es__ ## __LINE__ < ::Gecode::ES_OK) {                 \
@@ -106,13 +106,13 @@
  *
  * \ingroup TaskActor
  */
-#define GECODE_REWRITE(prop,post) do {                                  \
-  Propagator& __p__ ## __LINE__ = (prop);                               \
-  size_t     __s__ ## __LINE__  = __p__ ## __LINE__.dispose((home));    \
-  ExecStatus __es__ ## __LINE__ = (post);                               \
-  if (__es__ ## __LINE__ != ::Gecode::ES_OK)                            \
-    return ::Gecode::ES_FAILED;                                         \
-  return ES_SUBSUMED(__p__ ## __LINE__,__s__ ## __LINE__);              \
+#define GECODE_REWRITE(prop,post) do {                                   \
+  Propagator& __p__ ## __LINE__ = (prop);                                \
+  size_t     __s__ ## __LINE__  = __p__ ## __LINE__.dispose(home);       \
+  ExecStatus __es__ ## __LINE__ = (post);                                \
+  if (__es__ ## __LINE__ != ::Gecode::ES_OK)                             \
+    return ::Gecode::ES_FAILED;                                          \
+  return home.ES_SUBSUMED_DISPOSED(__p__ ## __LINE__,__s__ ## __LINE__); \
 } while (0)
 
 // STATISTICS: kernel-other
