@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2011-01-21 16:01:14 +0100 (Fri, 21 Jan 2011) $ by $Author: schulte $
- *     $Revision: 11553 $
+ *     $Date: 2012-02-22 16:04:20 +1100 (Wed, 22 Feb 2012) $ by $Author: tack $
+ *     $Revision: 12537 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -42,7 +42,7 @@ namespace Gecode {
    *
    */
   forceinline
-  BoolExpr::Node::Node(void) : use(1) {}
+  BoolExpr::Node::Node(void) : use(1), m(NULL) {}
 
   forceinline
   BoolExpr::Node::~Node(void) { delete m; }
@@ -65,9 +65,6 @@ namespace Gecode {
     heap.rfree(p);
   }
 
-  forceinline
-  BoolExpr::BoolExpr(void) : n(NULL) {}
-
   forceinline
   BoolExpr::BoolExpr(const BoolExpr& e) : n(e.n) {
     n->use++;
