@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-07-14 17:46:18 +0200 (Wed, 14 Jul 2010) $ by $Author: schulte $
- *     $Revision: 11192 $
+ *     $Date: 2011-04-05 23:56:09 +1000 (Tue, 05 Apr 2011) $ by $Author: tack $
+ *     $Revision: 11894 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -120,7 +120,7 @@ namespace Gecode {
     Set::Limits::check(lub,"SetVarArray::SetVarArray");
     Set::Limits::check(maxCard,"SetVarArray::SetVarArray");
     IntSetRanges glbr(glb);
-    IntSetRanges glbr_s(lub);
+    IntSetRanges glbr_s(glb);
     unsigned int glbSize = Iter::Ranges::size(glbr_s);
     IntSetRanges lubr(lub);
     IntSetRanges lubr_s(lub);
@@ -201,7 +201,7 @@ namespace Gecode {
     Set::Limits::check(lub,"SetVarArgs::SetVarArgs");
     Set::Limits::check(maxCard,"SetVarArgs::SetVarArgs");
     IntSetRanges glbr(glb);
-    IntSetRanges glbr_s(lub);
+    IntSetRanges glbr_s(glb);
     unsigned int glbSize = Iter::Ranges::size(glbr_s);
     IntSetRanges lubr(lub);
     IntSetRanges lubr_s(lub);
