@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,14 +45,14 @@ namespace Gecode {
   convex(Home home, SetVar x) {
     using namespace Gecode::Set;
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Convex::Convex::post(home, x));
+    GECODE_ES_FAIL(Convex::Convex::post(home, x));
   }
 
   void
   convex(Home home, SetVar x, SetVar y) {
     using namespace Gecode::Set;
     if (home.failed()) return;
-    GECODE_ES_FAIL(home,Convex::ConvexHull::post(home, x,y));
+    GECODE_ES_FAIL(Convex::ConvexHull::post(home, x,y));
   }
 
 }
