@@ -7,8 +7,8 @@
  *     Guido Tack, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -48,7 +48,7 @@ namespace Gecode {
     if (xa.size() < 2)
       return;
     ViewArray<SetView> x(home,xa);
-    GECODE_ES_FAIL(home,Distinct::AtmostOne::post(home, x, c));
+    GECODE_ES_FAIL(Distinct::AtmostOne::post(home, x, c));
   }
 
 }
