@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2011-09-19 14:02:26 +0200 (Mon, 19 Sep 2011) $ by $Author: schulte $
- *     $Revision: 12400 $
+ *     $Date: 2012-02-22 16:04:20 +1100 (Wed, 22 Feb 2012) $ by $Author: tack $
+ *     $Revision: 12537 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -280,8 +280,10 @@ namespace Gecode { namespace Set { namespace Element {
 
     } while (loopVar);
 
-    if (x0.assigned() || x1.assigned())
+    if (x1.assigned()) {
+      assert(x0.assigned());
       return home.ES_SUBSUMED(*this);
+    }
 
     return ES_FIX;
   }
