@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-31 00:34:12 +1100 (Wed, 31 Mar 2010) $ by $Author: tack $
+ *     $Revision: 10603 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -47,8 +47,8 @@ namespace Gecode { namespace Set { namespace Int {
   template<class View>
   forceinline
   Card<View>::Card(Home home, View y0, Gecode::Int::IntView y1)
-    : IntSetPropagator<View,PC_SET_CARD,
-                       Gecode::Int::PC_INT_BND> (home, y0, y1) {}
+    : MixBinaryPropagator<View,PC_SET_CARD,
+      Gecode::Int::IntView,Gecode::Int::PC_INT_BND> (home, y0, y1) {}
 
   template<class View>
   forceinline ExecStatus
@@ -62,8 +62,8 @@ namespace Gecode { namespace Set { namespace Int {
   template<class View>
   forceinline
   Card<View>::Card(Space& home, bool share, Card& p)
-    : IntSetPropagator<View,PC_SET_CARD,
-                       Gecode::Int::PC_INT_BND> (home, share, p) {}
+    : MixBinaryPropagator<View,PC_SET_CARD,
+      Gecode::Int::IntView,Gecode::Int::PC_INT_BND> (home, share, p) {}
 
   template<class View>
   Actor*
@@ -84,7 +84,7 @@ namespace Gecode { namespace Set { namespace Int {
      GECODE_ME_CHECK(x1.lq(home,static_cast<int>(x0.cardMax())));
    } while (x1.min() > x1min || x1.max() < x1max);
    if (x1.assigned())
-     return ES_SUBSUMED(*this,home);
+     return home.ES_SUBSUMED(*this);
    return ES_FIX;
   }
 
