@@ -10,8 +10,8 @@
  *     Guido Tack, 2004, 2005
  *
  *  Last modified:
- *     $Date: 2009-11-03 12:33:09 +0100 (Tue, 03 Nov 2009) $ by $Author: tack $
- *     $Revision: 10027 $
+ *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -51,15 +51,15 @@ namespace Gecode {
     ViewArray<SetView> xa(home,x);
     switch (op) {
     case SOT_UNION:
-      GECODE_ES_FAIL(home,(RelOp::UnionN<SetView,SetView>::post(home, xa, y)));
+      GECODE_ES_FAIL((RelOp::UnionN<SetView,SetView>::post(home, xa, y)));
       break;
     case SOT_DUNION:
-      GECODE_ES_FAIL(home,
+      GECODE_ES_FAIL(
                      (RelOp::PartitionN<SetView,SetView>::post(home, xa, y)));
       break;
     case SOT_INTER:
       {
-        GECODE_ES_FAIL(home,
+        GECODE_ES_FAIL(
                        (RelOp::IntersectionN<SetView,SetView>
                         ::post(home, xa, y)));
       }
@@ -79,15 +79,15 @@ namespace Gecode {
     ViewArray<SetView> xa(home,x);
     switch (op) {
     case SOT_UNION:
-      GECODE_ES_FAIL(home,(RelOp::UnionN<SetView,SetView>::post(home, xa, z, y)));
+      GECODE_ES_FAIL((RelOp::UnionN<SetView,SetView>::post(home, xa, z, y)));
       break;
     case SOT_DUNION:
-      GECODE_ES_FAIL(home,
+      GECODE_ES_FAIL(
                      (RelOp::PartitionN<SetView,SetView>::post(home, xa, z, y)));
       break;
     case SOT_INTER:
       {
-        GECODE_ES_FAIL(home,
+        GECODE_ES_FAIL(
                        (RelOp::IntersectionN<SetView,SetView>
                         ::post(home, xa, z, y)));
       }
