@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -126,13 +126,13 @@ namespace Gecode { namespace Set { namespace RelOp {
 
     if (shared(x0,x1,x2)) {
       if (allassigned) {
-        return ES_SUBSUMED(*this,home);
+        return home.ES_SUBSUMED(*this);
       } else {
         return ES_NOFIX;
       }
     } else {
       if (x0.assigned() + x1.assigned() + x2.assigned() >= 2) {
-         return ES_SUBSUMED(*this,home);
+         return home.ES_SUBSUMED(*this);
       } else {
         return ES_FIX;
       }
