@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -80,8 +80,8 @@ namespace Gecode { namespace Set { namespace Rel {
     GlbRanges<View0> x0lb(x0);
     LubRanges<View1> x1ub(x1);
     if (!Iter::Ranges::subset(x0lb, x1ub))
-      return ES_SUBSUMED(*this,home);
-    if (x0.cardMin()>x1.cardMax()) { return ES_SUBSUMED(*this,home); }
+      return home.ES_SUBSUMED(*this);
+    if (x0.cardMin()>x1.cardMax()) { return home.ES_SUBSUMED(*this); }
     LubRanges<View0> x0ub(x0);
     GlbRanges<View1> x1lb(x1);
     Iter::Ranges::Diff<LubRanges<View0>,GlbRanges<View1> >
@@ -94,7 +94,7 @@ namespace Gecode { namespace Set { namespace Rel {
       //Only one subsetness-breaker element left:
       GECODE_ME_CHECK( x0.include(home,b1) );
       GECODE_ME_CHECK( x1.exclude(home,b1) );
-      return ES_SUBSUMED(*this,home);
+      return home.ES_SUBSUMED(*this);
     }
     return ES_FIX;
   }
