@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-14 12:19:49 +0200 (Wed, 14 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9909 $
+ *     $Date: 2010-03-04 03:32:21 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10364 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -86,9 +86,9 @@ namespace Gecode { namespace Set { namespace Rel {
       GECODE_REWRITE(*this,(Eq<View0,View1>::post(home(*this),x0,x1)));
 
     if (shared(x0,x1)) {
-      return oneassigned ? ES_SUBSUMED(*this,home) : ES_NOFIX;
+      return oneassigned ? home.ES_SUBSUMED(*this) : ES_NOFIX;
     }
-    return (x0.assigned() || x1.assigned()) ? ES_SUBSUMED(*this,home) : ES_FIX;
+    return (x0.assigned() || x1.assigned()) ? home.ES_SUBSUMED(*this) : ES_FIX;
   }
 
 }}}
