@@ -9,8 +9,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-10-12 17:36:53 +0200 (Mon, 12 Oct 2009) $ by $Author: schulte $
- *     $Revision: 9878 $
+ *     $Date: 2010-03-04 03:40:32 +1100 (Thu, 04 Mar 2010) $ by $Author: schulte $
+ *     $Revision: 10365 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -49,14 +49,14 @@ namespace Gecode {
       throw TooFewArguments("Set::seq");
     if (home.failed()) return;
     ViewArray<SetView> x(home,xa);
-    GECODE_ES_FAIL(home,Sequence::Seq::post(home, x));
+    GECODE_ES_FAIL(Sequence::Seq::post(home, x));
   }
 
   void
   sequence(Home home, const SetVarArgs& xa, SetVar y) {
     if (home.failed()) return;
     ViewArray<SetView> x(home,xa);
-    GECODE_ES_FAIL(home,Sequence::SeqU::post(home, x,y));
+    GECODE_ES_FAIL(Sequence::SeqU::post(home, x,y));
   }
 
 }
