@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-06-30 14:31:56 +0200 (Wed, 30 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11134 $
+ *     $Date: 2010-09-01 00:19:34 +1000 (Wed, 01 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11366 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,13 +45,13 @@
 namespace Gecode {
 
   SetVar::SetVar(Space& home)
-    : Var<Set::SetVarImp>(new (home) Set::SetVarImp(home)) {}
+    : VarImpVar<Set::SetVarImp>(new (home) Set::SetVarImp(home)) {}
 
   SetVar::SetVar(Space& home,int lbMin,int lbMax,int ubMin,int ubMax,
                  unsigned int minCard, unsigned int maxCard)
-    : Var<Set::SetVarImp>(new (home) Set::SetVarImp(home,lbMin,lbMax,
-                                                        ubMin,ubMax,
-                                                        minCard,maxCard)) {
+    : VarImpVar<Set::SetVarImp>(new (home) Set::SetVarImp(home,lbMin,lbMax,
+                                                          ubMin,ubMax,
+                                                          minCard,maxCard)) {
     Set::Limits::check(lbMin,"SetVar::SetVar");
     Set::Limits::check(lbMax,"SetVar::SetVar");
     Set::Limits::check(ubMin,"SetVar::SetVar");
@@ -64,8 +64,8 @@ namespace Gecode {
 
   SetVar::SetVar(Space& home, const IntSet& glb,int ubMin,int ubMax,
                  unsigned int minCard, unsigned int maxCard)
-    : Var<Set::SetVarImp>(new (home) Set::SetVarImp(home,glb,ubMin,ubMax,
-                                                        minCard,maxCard)) {
+    : VarImpVar<Set::SetVarImp>(new (home) Set::SetVarImp(home,glb,ubMin,ubMax,
+                                                          minCard,maxCard)) {
     Set::Limits::check(glb,"SetVar::SetVar");
     Set::Limits::check(ubMin,"SetVar::SetVar");
     Set::Limits::check(ubMax,"SetVar::SetVar");
@@ -77,8 +77,8 @@ namespace Gecode {
 
   SetVar::SetVar(Space& home,int lbMin,int lbMax,const IntSet& lub,
                  unsigned int minCard, unsigned int maxCard)
-    : Var<Set::SetVarImp>(new (home) Set::SetVarImp(home,lbMin,lbMax,lub,
-                                                        minCard,maxCard)) {
+    : VarImpVar<Set::SetVarImp>(new (home) Set::SetVarImp(home,lbMin,lbMax,lub,
+                                                          minCard,maxCard)) {
     Set::Limits::check(lbMin,"SetVar::SetVar");
     Set::Limits::check(lbMax,"SetVar::SetVar");
     Set::Limits::check(lub,"SetVar::SetVar");
@@ -93,8 +93,8 @@ namespace Gecode {
   SetVar::SetVar(Space& home,
                  const IntSet& glb, const IntSet& lub,
                  unsigned int minCard, unsigned int maxCard)
-    : Var<Set::SetVarImp>(new (home) Set::SetVarImp(home,glb,lub,minCard,
-                                                        maxCard)) {
+    : VarImpVar<Set::SetVarImp>(new (home) Set::SetVarImp(home,glb,lub,minCard,
+                                                          maxCard)) {
     Set::Limits::check(glb,"SetVar::SetVar");
     Set::Limits::check(lub,"SetVar::SetVar");
     Set::Limits::check(maxCard,"SetVar::SetVar");
