@@ -11,8 +11,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-06-30 14:31:56 +0200 (Wed, 30 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11134 $
+ *     $Date: 2010-09-01 00:19:34 +1000 (Wed, 01 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11366 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -51,11 +51,11 @@ namespace Gecode {
 
   forceinline
   SetVar::SetVar(const SetVar& y)
-    : Var<Set::SetVarImp>(y.varimp()) {}
+    : VarImpVar<Set::SetVarImp>(y.varimp()) {}
 
   forceinline
   SetVar::SetVar(const Set::SetView& y)
-    : Var<Set::SetVarImp>(y.varimp()) {}
+    : VarImpVar<Set::SetVarImp>(y.varimp()) {}
 
 
   /*
