@@ -13,8 +13,8 @@
  *     Gabor Szokoli, 2004
  *
  *  Last modified:
- *     $Date: 2010-06-29 10:39:13 +0200 (Tue, 29 Jun 2010) $ by $Author: schulte $
- *     $Revision: 11118 $
+ *     $Date: 2010-09-01 01:19:33 +1000 (Wed, 01 Sep 2010) $ by $Author: schulte $
+ *     $Revision: 11368 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -52,10 +52,10 @@ namespace Gecode { namespace Set {
   SetView::SetView(void) {}
   forceinline
   SetView::SetView(const SetVar& y)
-    : VarImpView<SetVarImp>(y.varimp()) {}
+    : VarImpView<SetVar>(y.varimp()) {}
   forceinline
   SetView::SetView(SetVarImp* y)
-    : VarImpView<SetVarImp>(y) {}
+    : VarImpView<SetVar>(y) {}
 
   /*
    * Variable information
@@ -153,7 +153,6 @@ namespace Gecode { namespace Set {
 
   template<class I> ModEvent
   SetView::includeI (Space& home, I& iter) {
-    Iter::Ranges::IsRangeIter<I>();
     return x->includeI(home, iter);
   }
 
@@ -163,12 +162,10 @@ namespace Gecode { namespace Set {
   }
   template<class I> ModEvent
   SetView::excludeI(Space& home, I& iter) {
-    Iter::Ranges::IsRangeIter<I>();
     return x->excludeI(home, iter);
   }
   template<class I> ModEvent
   SetView::intersectI(Space& home, I& iter) {
-    Iter::Ranges::IsRangeIter<I>();
     return x->intersectI(home, iter);
   }
 
