@@ -11,8 +11,8 @@
  *     Christian Schulte, 2007
  *
  *  Last modified:
- *     $Date: 2009-12-02 21:53:32 +0100 (Wed, 02 Dec 2009) $ by $Author: schulte $
- *     $Revision: 10175 $
+ *     $Date: 2010-07-15 01:46:18 +1000 (Thu, 15 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11192 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -52,7 +52,7 @@ namespace Gecode { namespace Support {
     A& a;
   public:
     /// Bit set with space for \a s bits
-    BitSet(A& a, int s);
+    BitSet(A& a, unsigned int s);
     /// Copy bit set \a bs
     BitSet(A& a, const BitSet& bs);
     /// Destructor
@@ -61,7 +61,7 @@ namespace Gecode { namespace Support {
 
   template<class A>
   forceinline
-  BitSet<A>::BitSet(A& a0, int s)
+  BitSet<A>::BitSet(A& a0, unsigned int s)
     : BitSetBase(a0,s), a(a0) {}
 
   template<class A>
