@@ -7,8 +7,8 @@
  *     Christian Schulte, 2004
  *
  *  Last modified:
- *     $Date: 2009-09-08 21:10:29 +0200 (Tue, 08 Sep 2009) $ by $Author: schulte $
- *     $Revision: 9692 $
+ *     $Date: 2010-07-29 00:13:53 +1000 (Thu, 29 Jul 2010) $ by $Author: schulte $
+ *     $Revision: 11292 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -45,9 +45,11 @@ namespace Gecode { namespace Support {
    *
    * \ingroup FuncSupport
    */
-  template<class T, int blocksize = 512>
+  template<class T, class A, int blocksize = 512>
   class BlockAllocator {
   private:
+    /// Memory allocator
+    A& a;
     /// One block of memory
     class Block {
     public:
@@ -64,9 +66,11 @@ namespace Gecode { namespace Support {
     void allocate(void);
   public:
     /// Initialize
-    BlockAllocator(void);
+    BlockAllocator(A& a);
     /// Free all allocated blocks
     ~BlockAllocator(void);
+    /// Return allocator used
+    A& allocator(void);
     /// Return memory of size required by \a T
     T* operator ()(void);
     /// Return size of memory required by allocator
@@ -80,77 +84,83 @@ namespace Gecode { namespace Support {
    *
    * \ingroup FuncSupport
    */
-  template<class T, int blocksize = 512>
+  template<class T, class A, int blocksize = 512>
   class BlockClient {
   public:
     /// Allocate memory from block allocator \a ba
-    static void* operator new(size_t s, BlockAllocator<T,blocksize>& ba);
+    static void* operator new(size_t s, BlockAllocator<T,A,blocksize>& ba);
     /// Noop (memory freed only when block allocator deleted)
-    static void  operator delete(void*, BlockAllocator<T,blocksize>& ba);
+    static void  operator delete(void*, BlockAllocator<T,A,blocksize>& ba);
     /// Noop (memory freed only when block allocator deleted)
     static void  operator delete(void*);
   };
 
 
 
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
   forceinline
-  BlockAllocator<T,blocksize>::BlockAllocator(void) {
-    b = static_cast<Block*>(heap.ralloc(sizeof(Block)));
+  BlockAllocator<T,A,blocksize>::BlockAllocator(A& a0) : a(a0) {
+    b = static_cast<Block*>(a.ralloc(sizeof(Block)));
     b->next = NULL;
     n       = &b->b[blocksize];
     _size = sizeof(Block);
   }
 
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
   forceinline
-  BlockAllocator<T,blocksize>::~BlockAllocator(void) {
+  BlockAllocator<T,A,blocksize>::~BlockAllocator(void) {
     while (b != NULL) {
       Block* f = b; b = b->next;
-      heap.rfree(f);
+      a.rfree(f,sizeof(Block));
     }
   }
 
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
+  forceinline A&
+  BlockAllocator<T,A,blocksize>::allocator(void) {
+    return a;
+  }
+
+  template<class T, class A, int blocksize>
   forceinline T*
-  BlockAllocator<T,blocksize>::operator ()(void) {
+  BlockAllocator<T,A,blocksize>::operator ()(void) {
     T* t = --n;
     if (t == &b->b[0])
       allocate();
     return t;
   }
 
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
   void
-  BlockAllocator<T,blocksize>::allocate(void) {
+  BlockAllocator<T,A,blocksize>::allocate(void) {
     // Allocate another block
-    Block* nb = static_cast<Block*>(heap.ralloc(sizeof(Block)));
+    Block* nb = static_cast<Block*>(a.ralloc(sizeof(Block)));
     nb->next = b; b = nb;
     n = &nb->b[blocksize];
     _size += sizeof(Block);
   }
 
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
   forceinline size_t
-  BlockAllocator<T,blocksize>::size(void) const {
+  BlockAllocator<T,A,blocksize>::size(void) const {
     return _size;
   }
 
 
 
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
   forceinline void
-  BlockClient<T,blocksize>::operator delete(void*,
-                                            BlockAllocator<T,blocksize>&) {
+  BlockClient<T,A,blocksize>::operator 
+  delete(void*,BlockAllocator<T,A,blocksize>&) {
   }
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
   forceinline void
-  BlockClient<T,blocksize>::operator delete(void*) {
+  BlockClient<T,A,blocksize>::operator delete(void*) {
   }
-  template<class T, int blocksize>
+  template<class T, class A, int blocksize>
   forceinline void*
-  BlockClient<T,blocksize>::operator new(size_t,
-                                         BlockAllocator<T,blocksize>& ba) {
+  BlockClient<T,A,blocksize>::operator new(size_t,
+                                           BlockAllocator<T,A,blocksize>& ba) {
     return ba();
   }
 
