@@ -7,8 +7,8 @@
  *     Christian Schulte, 2005
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2011-08-22 21:08:29 +1000 (Mon, 22 Aug 2011) $ by $Author: schulte $
+ *     $Revision: 12326 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -66,7 +66,31 @@ namespace Test { namespace Int {
        }
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
-         Gecode::count(home, x,0,irt,2);
+         Gecode::count(home, x, 0, irt, 2);
+       }
+     };
+
+     /// %Test number of integers contained in an integer set equal to integer
+     class SetInt : public Test {
+     protected:
+       /// Integer relation type to propagate
+       Gecode::IntRelType irt;
+     public:
+       /// Create and register test
+       SetInt(Gecode::IntRelType irt0)
+         : Test("Count::Set::Int::"+str(irt0),4,-2,2), irt(irt0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         int m = 0;
+         for (int i=x.size(); i--; )
+           if ((x[i] >= -1) && (x[i] <= 1))
+             m++;
+         return cmp(m,irt,2);
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         Gecode::IntSet s(-1,1);
+         Gecode::count(home, x, s, irt, 2);
        }
      };
 
@@ -122,6 +146,33 @@ namespace Test { namespace Int {
        }
      };
 
+     /// %Test number of integers contained in an integer set equal to integer variable
+     class SetVar : public Test {
+     protected:
+       /// Integer relation type to propagate
+       Gecode::IntRelType irt;
+     public:
+       /// Create and register test
+       SetVar(Gecode::IntRelType irt0)
+         : Test("Count::Set::Var::"+str(irt0),5,-2,2), irt(irt0) {}
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         int m = 0;
+         for (int i=0; i<4; i++)
+           if ((x[i] >= -1) && (x[i] <= 1))
+             m++;
+         return cmp(m,irt,x[4]);
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         Gecode::IntVarArgs y(4);
+         for (int i=0; i<4; i++)
+           y[i]=x[i];
+         Gecode::IntSet s(-1,1);
+         Gecode::count(home, y, s, irt, x[4]);
+       }
+     };
+
      Gecode::IntArgs ints(4, 1,0,3,2);
 
      /// %Test number of several equal integers equal to integer
@@ -311,7 +362,7 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        VarVarSharedC(Gecode::IntRelType irt0)
-         : Test("Count::Var::Var::Shared::A::"+str(irt0),4,-2,2), irt(irt0) {}
+         : Test("Count::Var::Var::Shared::C::"+str(irt0),4,-2,2), irt(irt0) {}
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          int m = 0;
@@ -333,8 +384,10 @@ namespace Test { namespace Int {
        Create(void) {
          for (IntRelTypes irts; irts(); ++irts) {
            (void) new IntInt(irts.irt());
+           (void) new SetInt(irts.irt());
            (void) new IntIntDup(irts.irt());
            (void) new IntVar(irts.irt());
+           (void) new SetVar(irts.irt());
            (void) new IntArrayInt(irts.irt());
            (void) new IntArrayVar(irts.irt());
            (void) new IntVarShared(irts.irt());
