@@ -7,8 +7,8 @@
  *     Christian Schulte, 2008
  *
  *  Last modified:
- *     $Date: 2010-04-08 12:35:31 +0200 (Thu, 08 Apr 2010) $ by $Author: schulte $
- *     $Revision: 10684 $
+ *     $Date: 2010-07-16 06:33:36 +1000 (Fri, 16 Jul 2010) $ by $Author: tack $
+ *     $Revision: 11206 $
  *
  *  This file is part of Gecode, the generic constraint
  *  development environment:
@@ -54,7 +54,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        Mult(const std::string& s, const Gecode::IntSet& d)
-         : Test("MiniModel::Mult::"+s,3,d) {}
+         : Test("MiniModel::Mult::"+s,3,d) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          double d0 = static_cast<double>(x[0]);
@@ -65,7 +67,45 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, mult(home, x[0], x[1]), IRT_EQ, x[2], ICL_DOM);
+         rel(home, expr(home, x[0] * x[1]), IRT_EQ, x[2], ICL_DOM);
+       }
+     };
+
+     /// %Test for division constraint
+     class Div : public Test {
+     public:
+       /// Create and register test
+       Div(const std::string& s, const Gecode::IntSet& d)
+         : Test("MiniModel::Div::"+s,3,d) {
+         testfix = false;
+       }
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         return (x[1] != 0) && (x[0] / x[1] == x[2]);
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         rel(home, expr(home, x[0] / x[1]), IRT_EQ, x[2], ICL_DOM);
+       }
+     };
+
+     /// %Test for division constraint
+     class Mod : public Test {
+     public:
+       /// Create and register test
+       Mod(const std::string& s, const Gecode::IntSet& d)
+         : Test("MiniModel::Mod::"+s,3,d) {
+         testfix = false;
+       }
+       /// %Test whether \a x is solution
+       virtual bool solution(const Assignment& x) const {
+         return (x[1] != 0) && (x[0] % x[1] == x[2]);
+       }
+       /// Post constraint on \a x
+       virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
+         using namespace Gecode;
+         rel(home, expr(home, x[0] % x[1]), IRT_EQ, x[2], ICL_DOM);
        }
      };
 
@@ -74,7 +114,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        Plus(const std::string& s, const Gecode::IntSet& d)
-         : Test("MiniModel::Plus::"+s,3,d) {}
+         : Test("MiniModel::Plus::"+s,3,d) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          double d0 = static_cast<double>(x[0]);
@@ -87,7 +129,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, plus(home, x[0], x[1]), IRT_EQ, x[2], ICL_DOM);
+         rel(home, expr(home, x[0] + x[1]), IRT_EQ, x[2], ICL_DOM);
        }
      };
 
@@ -96,7 +138,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        Minus(const std::string& s, const Gecode::IntSet& d)
-         : Test("MiniModel::Minus::"+s,3,d) {}
+         : Test("MiniModel::Minus::"+s,3,d) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          double d0 = static_cast<double>(x[0]);
@@ -109,7 +153,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, minus(home, x[0], x[1]), IRT_EQ, x[2], ICL_DOM);
+         rel(home, expr(home, x[0] - x[1]), IRT_EQ, x[2], ICL_DOM);
        }
      };
 
@@ -118,7 +162,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        Sqr(const std::string& s, const Gecode::IntSet& d)
-         : Test("MiniModel::Sqr::"+s,2,d) {}
+         : Test("MiniModel::Sqr::"+s,2,d) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          double d0 = static_cast<double>(x[0]);
@@ -128,7 +174,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, sqr(home, x[0]), IRT_EQ, x[1], ICL_DOM);
+         rel(home, expr(home, sqr(x[0])), IRT_EQ, x[1], ICL_DOM);
        }
      };
 
@@ -137,7 +183,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        Sqrt(const std::string& s, const Gecode::IntSet& d)
-         : Test("MiniModel::Sqrt::"+s,2,d) {}
+         : Test("MiniModel::Sqrt::"+s,2,d) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          double d0 = static_cast<double>(x[0]);
@@ -147,7 +195,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, sqrt(home,x[0]), IRT_EQ, x[1], ICL_DOM);
+         rel(home, expr(home, sqrt(x[0])), IRT_EQ, x[1], ICL_DOM);
        }
      };
 
@@ -157,7 +205,9 @@ namespace Test { namespace Int {
        /// Create and register test
        Abs(const std::string& s, const Gecode::IntSet& d, Gecode::IntConLevel icl)
          : Test("MiniModel::Abs::"+str(icl)+"::"+s,
-                   2,d,false,icl) {}
+                   2,d,false,icl) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          double d0 = static_cast<double>(x[0]);
@@ -167,7 +217,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, abs(home, x[0], icl), IRT_EQ, x[1], ICL_DOM);
+         rel(home, expr(home, abs(x[0]), icl), IRT_EQ, x[1], ICL_DOM);
        }
      };
 
@@ -176,7 +226,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        Min(const std::string& s, const Gecode::IntSet& d)
-         : Test("MiniModel::Min::Bin::"+s,3,d) {}
+         : Test("MiniModel::Min::Bin::"+s,3,d) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          return std::min(x[0],x[1]) == x[2];
@@ -184,7 +236,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, min(home, x[0], x[1]), IRT_EQ, x[2], ICL_DOM);
+         rel(home, expr(home, min(x[0], x[1])), IRT_EQ, x[2], ICL_DOM);
        }
      };
 
@@ -193,7 +245,9 @@ namespace Test { namespace Int {
      public:
        /// Create and register test
        Max(const std::string& s, const Gecode::IntSet& d)
-         : Test("MiniModel::Max::Bin::"+s,3,d) {}
+         : Test("MiniModel::Max::Bin::"+s,3,d) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          return std::max(x[0],x[1]) == x[2];
@@ -201,7 +255,7 @@ namespace Test { namespace Int {
        /// Post constraint on \a x
        virtual void post(Gecode::Space& home, Gecode::IntVarArray& x) {
          using namespace Gecode;
-         rel(home, max(home, x[0], x[1]), IRT_EQ, x[2], ICL_DOM);
+         rel(home, expr(home, max(x[0], x[1])), IRT_EQ, x[2], ICL_DOM);
        }
      };
 
@@ -209,7 +263,9 @@ namespace Test { namespace Int {
      class MinNary : public Test {
      public:
        /// Create and register test
-       MinNary(void) : Test("MiniModel::Min::Nary",4,-4,4) {}
+       MinNary(void) : Test("MiniModel::Min::Nary",4,-4,4) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          return std::min(std::min(x[0],x[1]), x[2]) == x[3];
@@ -219,7 +275,7 @@ namespace Test { namespace Int {
          using namespace Gecode;
          IntVarArgs m(3);
          m[0]=x[0]; m[1]=x[1]; m[2]=x[2];
-         rel(home, min(home, m), IRT_EQ, x[3], ICL_DOM);
+         rel(home, expr(home, min(m)), IRT_EQ, x[3], ICL_DOM);
        }
      };
 
@@ -227,7 +283,9 @@ namespace Test { namespace Int {
      class MaxNary : public Test {
      public:
        /// Create and register test
-       MaxNary(void) : Test("MiniModel::Max::Nary",4,-4,4) {}
+       MaxNary(void) : Test("MiniModel::Max::Nary",4,-4,4) {
+         testfix = false;
+       }
        /// %Test whether \a x is solution
        virtual bool solution(const Assignment& x) const {
          return std::max(std::max(x[0],x[1]), x[2]) == x[3];
@@ -237,7 +295,7 @@ namespace Test { namespace Int {
          using namespace Gecode;
          IntVarArgs m(3);
          m[0]=x[0]; m[1]=x[1]; m[2]=x[2];
-         rel(home, max(home, m), IRT_EQ, x[3], ICL_DOM);
+         rel(home, expr(home, max(m)), IRT_EQ, x[3], ICL_DOM);
        }
      };
 
@@ -260,6 +318,14 @@ namespace Test { namespace Int {
      Mult mult_med("B",d2);
      Mult mult_min("C",d3);
 
+     Div div_max("A",d1);
+     Div div_med("B",d2);
+     Div div_min("C",d3);
+
+     Mod mod_max("A",d1);
+     Mod mod_med("B",d2);
+     Mod mod_min("C",d3);
+
      Plus plus_max("A",d1);
      Plus plus_med("B",d2);
      Plus plus_min("C",d3);
